import { Construct } from "@aws-cdk/core";
export interface IConstructConfig {
    /**
     * Whether the construct should create a route53 record or not.
     *
     * @default true
     **/
    useRoute53?: boolean;
    /**
     * Whether the construct should create a cloudfront distribution or not.
     *
     * @default true
     **/
    useCloudfront?: boolean;
    /**
     * Whether the bucket should be deleteable on cdk destroy or not.
     *
     * @default false
     **/
    useDeletableBucket?: boolean;
}
export interface StaticSiteProps {
    /**
     * Sub domain to use - added as a prefix to the domain name.
     **/
    siteSubDomain?: string;
    /**
     * Domain name to use. Should be the value of a hosted zone.
     **/
    domainName: string;
    /**
     * Location of the directory containing the files to be hosted.
     **/
    siteAssetsPath: string;
    /**
     * Configuration for the constructs to use.
     **/
    constructConfig?: IConstructConfig;
}
export default class StaticSite extends Construct {
    constructor(scope: Construct, id: string, props: StaticSiteProps);
}
